@@ -1,12 +1,13 @@
 import databases
 from sqlalchemy import MetaData, Table, Column, Integer, String, Boolean, Index, create_engine
+from sqlalchemy.engine import Engine
 
 from .settings import get_global_settings
 
 metadata = MetaData()
 settings = get_global_settings()
-database = databases.Database(settings.database_url)
-global_engine = None
+database: databases.Database = databases.Database(settings.database_url)
+engine: Engine = None
 
 redirects = Table(
     'redirect',
@@ -20,9 +21,9 @@ redirects = Table(
 Index('custom_targets', redirects.c.target, redirects.c.is_custom)
 
 
-def get_engine():
-    global global_engine
-    if not global_engine:
-        global_engine = create_engine(settings.database_url, connect_args={'check_same_thread': False})
-        metadata.create_all(global_engine)
-    return global_engine
+def init_engine(apply_schema: bool = False):
+    global engine
+    if not engine:
+        engine = create_engine(settings.database_url, connect_args={'check_same_thread': False})
+        if apply_schema:
+            metadata.create_all(engine)
