@@ -2,7 +2,7 @@ from pathlib import Path
 
 from pydantic import BaseSettings, Field, AnyUrl, RedisDsn
 
-from utils.cache import redis_installed
+from .utils.cache import redis_installed
 
 APP_PATH = Path(__file__).parent.absolute()
 
